<?php 
/**
 * Custom theme functions.
 *
 * This file contains hook functions attached to theme hooks.
 *
 * @package PressPen
 */
if ( ! function_exists( 'presspen_header' ) ) :
	function presspen_header(){?>

<header class="nav-header">
	<div class="container">
		<div class="brand text-center mx-auto">
			<?php presspen_site_logo(); ?>
			<?php presspen_site_description();?>
		</div>
		<!--Navbar -->
		<nav class="navbar navbar-expand-lg navbar-light bg-theme">
			<button class="navbar-toggler" type="button" data-toggle="collapse" data-target="#navbar-collapse"
				aria-controls="navbar-collapse" aria-expanded="false"
				aria-label="<?php esc_attr_e( 'Toggle navigation', 'presspen' ); ?>">
				<span class="toggle-menu fa fa-bars"></span>
			</button>
			<?php
				wp_nav_menu( array(
					'theme_location'    => 'primary',
					'depth'             => 3,
					'container'         => 'div',
					'container_class'   => 'collapse navbar-collapse justify-content-center',
					'container_id'      => 'navbar-collapse',
					'menu_class'        => 'nav navbar-nav',
					'items_wrap'		=> '<ul class="nav navbar-nav" data-function="navbar">%3$s</ul>',
				) );
			?>
		
		</nav><!--/navbar-->
	</div>
  
    
</header>
<?php
	}
endif;
add_action('presspen_action_header','presspen_header', 10);

/**
Footer hook function
**/
if ( ! function_exists( 'presspen_footer' ) ) :
	function presspen_footer(){?>
<!--Footer-->
<footer class="footer sec-bg">
    <div class="container">
        <div class="row text-left mt-4 mb-4">
		<?php
			if (is_active_sidebar('footer_menu')) {
				dynamic_sidebar('footer_menu');
			}
		?>
        </div>
        <hr>
        <div class="row copyright_info">
            <div class="col-md-12">
                <div class="mt-2">
                    <?php
					if (!is_active_sidebar('copyright')) {
					?>
                    <div class="footer-credits">
                        <p class="footer-copyright powered-by-wordpress">
                            &copy;
                            <?php
							echo date_i18n(
								/* translators: Copyright date format, see https://secure.php.net/date */
								_x( 'Y', 'copyright date format', 'presspen' )
							);
							?>
									
							<a href="<?php echo esc_url( home_url( '/' ) ); ?>"><?php bloginfo( 'name' ); ?>.</a>
							<a href="<?php echo esc_url( __( 'https://wordpress.org/', 'presspen' ) ); ?>">
							<?php _e( 'Powered by WordPress', 'presspen' ); ?>
							</a>
                        </p><!-- .powered-by-wordpress -->
                    </div><!-- .footer-credits -->
                    <?php } else{?>
                    <small><?php dynamic_sidebar('copyright');?> </small>
                    <?php }?>
                </div>
            </div>
        </div>
    </div>
</footer>
<?php
	}
endif;
add_action('presspen_action_footer','presspen_footer', 10);

/** 
	Post Slide 
**/
if ( ! function_exists( 'presspen_blog_slider' ) ) :
function presspen_blog_slider(){

 if(has_post_thumbnail()):
?>
	<div class="slide-grid">
		<div class="blog-slider">
			<?php
           
            global $post;
			$args = array(
				'category'       	=> get_theme_mod('select_cat'),
				'posts_per_page' 	=> get_theme_mod('slider_blog_number'),
				'orderby'          	=> get_theme_mod('order_by_setting'),
				'order'            	=> get_theme_mod('order_setting'),
			);
			$query = get_posts($args);
				foreach ( $query as $post ) :// phpcs:ignore WordPress.WP.GlobalVariablesOverride
				 ?>
				<figure class="effect-steve">
					 <?php 
						presspen_post_thumbnail();
					 ?>
					<div class="slide-wrapper">
					  <div class="slide-text">
						<div class="cat">
							<?php presspen_get_category();?>
						</div>
						<div class="slide-heading">
							<?php the_title( '<h2 class="slider-post-title"><a href="' . esc_url( get_permalink() ) . '" rel="bookmark">', '</a></h2>' );?>
						</div>
						  <div class="slide-body">
							<?php echo presspen_get_excerpt(90); ?>
						  </div>
						</div>
					</div>
				</figure>
				<?php
			endforeach; 
			wp_reset_postdata();
			?>
		</div>
		<button class="slick-nav slick-prev slick-arrow">
		<svg version="1.1" xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink" x="0px" y="0px" width="15.983px" height="11.837px" viewBox="0 0 15.983 11.837" enable-background="new 0 0 15.983 11.837" xml:space="preserve"><path class="thb-arrow-head" d="M1.486,5.924l4.845-4.865c0.24-0.243,0.24-0.634,0-0.876c-0.242-0.243-0.634-0.243-0.874,0L0.18,5.481
	c-0.24,0.242-0.24,0.634,0,0.876l5.278,5.299c0.24,0.241,0.632,0.241,0.874,0c0.24-0.241,0.24-0.634,0-0.876L1.486,5.924z"></path><path class="pp-arrow-line" d="M15.982,5.92c0,0.328-0.264,0.593-0.592,0.593H0.592C0.264,6.513,0,6.248,0,5.92c0-0.327,0.264-0.591,0.592-0.591h14.799
	C15.719,5.329,15.982,5.593,15.982,5.92z"></path></svg>
		</button>
		<button class="slick-nav slick-next slick-arrow">
			<svg version="1.1" xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink" x="0px" y="0px" width="15.983px" height="11.837px" viewBox="0 0 15.983 11.837" enable-background="new 0 0 15.983 11.837" xml:space="preserve"><path class="thb-arrow-head" d="M9.651,10.781c-0.24,0.242-0.24,0.635,0,0.876c0.242,0.241,0.634,0.241,0.874,0l5.278-5.299c0.24-0.242,0.24-0.634,0-0.876
l-5.278-5.299c-0.24-0.243-0.632-0.243-0.874,0c-0.24,0.242-0.24,0.634,0,0.876l4.845,4.865L9.651,10.781z"></path><path class="pp-arrow-line" d="M0.591,5.329h14.799c0.328,0,0.592,0.265,0.592,0.591c0,0.328-0.264,0.593-0.592,0.593H0.591C0.264,6.513,0,6.248,0,5.92
C0,5.593,0.264,5.329,0.591,5.329z"></path></svg>
		</button>
	</div>
<?php
endif;
}
endif;
/** 
	Post Slide Hooked
**/
add_action('presspen_blog_slider_action','presspen_blog_slider', 10);

// Author Box.
if ( ! function_exists( 'presspen_author' ) ) :
function presspen_author( $id ) {
	$id = $id ? $id : get_the_author_meta( 'ID' );
	?>
	<div class="row author-content">
		<div class="col-md-3">
			<?php echo get_avatar( $id, '164', '', '', array( 'class' => 'lazy-load' ) ); ?>
		</div>
		<div class="col-md-9">
			<h4 class="mb-2">
				<a href="<?php echo get_author_posts_url( $id ); ?>">
				<?php the_author_meta( 'display_name', $id ); ?>
				</a>
			</h4>
			<p>
			<?php the_author_meta( 'description', $id ); ?>
			</p>
			<?php if ( get_the_author_meta( 'url', $id ) !== '' ) { ?>
				<a href="<?php echo get_the_author_meta( 'url', $id ); ?>" target="_blank"><i class="fa fa-link"></i></a>
			<?php } ?>
		</div>
	</div>
	<?php if ( is_author() ):?>
		<div class="clearfix"></div>
		<h5 class="mt-5"><?php _e('Posts by','presspen')?> 
			<?php the_author_meta( 'display_name', $id ); ?>:
		</h5>
		<hr>
	<?php
	endif;
}
endif;
add_action( 'presspen_author', 'presspen_author', 3 );